@@ -1,12 +1,17 @@
 
-package 
+package
 AWS::S3::Request::ListBucket;
 
 use VSO;
-use AWS::S3::HTTPRequest;
 
 extends 'AWS::S3::Request';
 
+has 'bucket' => (
+  is        => 'ro',
+  isa       => 'Str',
+  required  => 1,
+);
+
 has 'max_keys' => (
   is        => 'ro',
   isa       => 'Int',
@@ -31,7 +36,8 @@ has 'delimiter' => (
   required  => 0,
 );
 
-sub http_request
+
+sub request
 {
   my $s = shift;
   
@@ -40,13 +46,28 @@ sub http_request
   push @params, 'marker=' . $s->marker if $s->marker;
   push @params, 'prefix=' . $s->prefix if $s->prefix;
   push @params, 'delimiter=' . $s->delimiter if $s->delimiter;
-  return AWS::S3::HTTPRequest->new(
-    s3     => $s->s3,
-    method => 'GET',
-    path   => $s->_uri('') . '?' . join( '&', @params),
-  )->http_request;
+  my $signer = AWS::S3::Signer->new(
+    s3            => $s->s3,
+    method        => 'GET',
+    uri           => $s->protocol . '://' . $s->bucket . '.s3.amazonaws.com/' . ( @params ? '?' . join( '&', @params) : ''),
+  );
+  $s->_send_request( $signer->method => $signer->uri => {
+    Authorization => $signer->auth_header,
+    Date          => $signer->date,
+  });
+}# end request()
+
+sub parse_response
+{
+  my ($s, $res) = @_;
   
+  AWS::S3::ResponseParser->new(
+    response        => $res,
+    expect_nothing  => 0,
+    type            => $s->type,
+  );
 }# end http_request()
 
+
 1;# return true:
 
